@@ -31,7 +31,7 @@ class Metadata(DataSourceOutput):
         """Make a xr dataset"""
         if t0_dt is None:
             t0_dt, _, _ = make_random_time_vectors(
-                batch_size=batch_size, seq_len_5_minutes=0, seq_len_30_minutes=0
+                batch_size=batch_size, seq_length_5_minutes=0, seq_length_30_minutes=0
             )
 
         return Metadata(
